@@ -531,7 +531,7 @@ ret_t
 cherokee_buffer_encode_md5 (cherokee_buffer_t *buf)
 {
 	int i;
-	MD5_CTX context;
+	struct MD5Context context;
 	unsigned char digest[16];
 
 	MD5Init (&context);
