@@ -426,6 +426,12 @@ cherokee_connection_send_header (cherokee_connection_t *cnt)
 	 */
 	if (! http_type_200(cnt->error_code)) {
 		cherokee_buffer_add (cnt->buffer, "Content-Type: text/html"CRLF, 25);		
+
+		/* Add no-cache headers
+		 */
+		cherokee_buffer_add (cnt->buffer, "Cache-Control: no-cache"CRLF, 25);		
+		cherokee_buffer_add (cnt->buffer, "Pragma: no-cache"CRLF, 18);		
+		cherokee_buffer_add (cnt->buffer, "P3P: CP=3DNOI NID CURa OUR NOR UNI"CRLF, 36);		
 	}
 
 	/* Maybe the handler add some headers from the handler
