@@ -49,7 +49,12 @@ cherokee_handler_common_new (cherokee_handler_t **hdl, void *cnt, cherokee_table
 	cherokee_connection_t *conn = CONN(cnt);
 	cherokee_server_t     *srv  = CONN_SRV(cnt);
 
-	cherokee_buffer_add (conn->local_directory, conn->request->buf, conn->request->len);
+#if 0
+	PRINT_DEBUG ("request: '%s'\n", conn->request->buf);
+	PRINT_DEBUG ("local:   '%s'\n", conn->local_directory->buf);
+#endif
+
+	cherokee_buffer_add_buffer (conn->local_directory, conn->request);
 
 	/* Request is a directory
 	 */
@@ -66,7 +71,7 @@ cherokee_handler_common_new (cherokee_handler_t **hdl, void *cnt, cherokee_table
 			/* Add the index file
 			 */
 			cherokee_buffer_add (conn->local_directory, index, index_len);
-			
+
 			/* stat() it
 			 */
 			exists = (stat (conn->local_directory->buf, &info) == 0);
@@ -92,9 +97,7 @@ cherokee_handler_common_new (cherokee_handler_t **hdl, void *cnt, cherokee_table
 			 */
 			cherokee_buffer_add (conn->request, index, index_len);
 			
-			if ((conn->local_directory->len > 5) &&
-			    (strcasecmp(".php", conn->local_directory->buf + conn->local_directory->len -4) == 0))
-			{
+			if ((index_len > 4) && (strcasecmp(".php", index+index_len-4) == 0)) {
 				return cherokee_handler_phpcgi_new (hdl, cnt, properties);		
 			} else {
 				return cherokee_handler_file_new (hdl, cnt, properties);
