@@ -187,14 +187,18 @@
  * USA
  */
 
+#include "common.h"
+
 #include <pwd.h>
 #include <grp.h>
 #include <stdio.h>
 #include <sys/types.h>
+#include <sys/stat.h>
 #include <unistd.h>
+#include <dirent.h>
+#include <errno.h>
 
 #include "mime.h"
-#include "common.h"
 #include "server.h"
 #include "table.h"
 #include "virtual_server.h"
@@ -223,7 +227,7 @@
 #endif
 
 #if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
-#line 48 "read_config_grammar.y"
+#line 52 "read_config_grammar.y"
 typedef union YYSTYPE {
 	   int   number;
 	   char *string;
@@ -237,7 +241,7 @@ typedef union YYSTYPE {
 	   void *id_list;
 } YYSTYPE;
 /* Line 191 of yacc.c.  */
-#line 241 "read_config_grammar.c"
+#line 245 "read_config_grammar.c"
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
 # define YYSTYPE_IS_TRIVIAL 1
@@ -246,7 +250,7 @@ typedef union YYSTYPE {
 
 
 /* Copy the second part of user declarations.  */
-#line 62 "read_config_grammar.y"
+#line 66 "read_config_grammar.y"
 
 /* What is the right way to import this prototipe?
  */
@@ -358,7 +362,7 @@ yyerror(char* msg)
 
 
 /* Line 214 of yacc.c.  */
-#line 362 "read_config_grammar.c"
+#line 366 "read_config_grammar.c"
 
 #if ! defined (yyoverflow) || YYERROR_VERBOSE
 
@@ -568,18 +572,18 @@ static const yysigned_char yyrhs[] =
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const unsigned short yyrline[] =
 {
-       0,   190,   190,   191,   194,   195,   198,   199,   202,   203,
-     206,   207,   208,   209,   210,   211,   212,   213,   214,   215,
-     216,   217,   218,   219,   220,   221,   222,   223,   224,   225,
-     226,   229,   230,   231,   232,   233,   234,   235,   238,   239,
-     242,   243,   246,   247,   250,   251,   253,   262,   272,   277,
-     282,   297,   296,   322,   323,   325,   326,   329,   342,   347,
-     352,   360,   365,   373,   378,   383,   400,   417,   435,   448,
-     447,   478,   499,   520,   537,   542,   549,   554,   569,   574,
-     589,   594,   600,   607,   612,   617,   620,   623,   626,   629,
-     632,   636,   665,   666,   673,   672,   697,   696,   774,   780,
-     791,   795,   804,   825,   826,   829,   830,   833,   838,   869,
-     881,   893
+       0,   193,   193,   194,   197,   198,   201,   202,   205,   206,
+     209,   210,   211,   212,   213,   214,   215,   216,   217,   218,
+     219,   220,   221,   222,   223,   224,   225,   226,   227,   228,
+     229,   232,   233,   234,   235,   236,   237,   238,   241,   242,
+     245,   246,   249,   250,   253,   254,   256,   265,   275,   280,
+     285,   300,   299,   325,   326,   328,   329,   332,   345,   350,
+     355,   363,   368,   376,   381,   386,   403,   420,   438,   451,
+     450,   481,   502,   523,   540,   545,   552,   557,   572,   577,
+     592,   597,   603,   610,   615,   620,   623,   626,   629,   632,
+     635,   639,   668,   669,   675,   674,   699,   698,   776,   782,
+     793,   797,   806,   827,   828,   831,   832,   835,   840,   871,
+     883,   895
 };
 #endif
 
@@ -1407,7 +1411,7 @@ yyreduce:
   switch (yyn)
     {
         case 46:
-#line 254 "read_config_grammar.y"
+#line 257 "read_config_grammar.y"
     {
 	   linked_list_t *n = (linked_list_t *) malloc(sizeof(linked_list_t));
 	   n->next = NULL;
@@ -1418,7 +1422,7 @@ yyreduce:
     break;
 
   case 47:
-#line 263 "read_config_grammar.y"
+#line 266 "read_config_grammar.y"
     {
 	   linked_list_t *n = (linked_list_t *) malloc(sizeof(linked_list_t));
 
@@ -1430,21 +1434,21 @@ yyreduce:
     break;
 
   case 48:
-#line 273 "read_config_grammar.y"
+#line 276 "read_config_grammar.y"
     {
 	   SRV(server)->port = yyvsp[0].number;
 }
     break;
 
   case 49:
-#line 278 "read_config_grammar.y"
+#line 281 "read_config_grammar.y"
     {
 	   SRV(server)->listen_to = yyvsp[0].string;
 }
     break;
 
   case 50:
-#line 283 "read_config_grammar.y"
+#line 286 "read_config_grammar.y"
     {
 	   cherokee_virtual_server_t *vserver;
 
@@ -1459,7 +1463,7 @@ yyreduce:
     break;
 
   case 51:
-#line 297 "read_config_grammar.y"
+#line 300 "read_config_grammar.y"
     {
 	   ret_t ret;
 
@@ -1476,7 +1480,7 @@ yyreduce:
     break;
 
   case 52:
-#line 311 "read_config_grammar.y"
+#line 314 "read_config_grammar.y"
     {
 	   cherokee_virtual_server_t *vserver;
 	   vserver = auto_virtual_server;
@@ -1490,7 +1494,7 @@ yyreduce:
     break;
 
   case 57:
-#line 330 "read_config_grammar.y"
+#line 333 "read_config_grammar.y"
     {
 	   cherokee_virtual_server_t *vserver;
 	   vserver = auto_virtual_server;
@@ -1504,21 +1508,21 @@ yyreduce:
     break;
 
   case 58:
-#line 343 "read_config_grammar.y"
+#line 346 "read_config_grammar.y"
     {
 	   SRV(server)->hideversion = yyvsp[0].number;
 }
     break;
 
   case 59:
-#line 348 "read_config_grammar.y"
+#line 351 "read_config_grammar.y"
     {
 	   SRV(server)->hideservername = yyvsp[0].number;
 }
     break;
 
   case 60:
-#line 353 "read_config_grammar.y"
+#line 356 "read_config_grammar.y"
     {
 	   cherokee_mime_t *mime;
 
@@ -1528,14 +1532,14 @@ yyreduce:
     break;
 
   case 61:
-#line 361 "read_config_grammar.y"
+#line 364 "read_config_grammar.y"
     {
 	   SRV(server)->icons_file = yyvsp[0].string;
 }
     break;
 
   case 62:
-#line 366 "read_config_grammar.y"
+#line 369 "read_config_grammar.y"
     {
 	   SRV(server)->timeout = yyvsp[0].number;
 
@@ -1545,21 +1549,21 @@ yyreduce:
     break;
 
   case 63:
-#line 374 "read_config_grammar.y"
+#line 377 "read_config_grammar.y"
     {
 	   SRV(server)->keepalive = yyvsp[0].number;
 }
     break;
 
   case 64:
-#line 379 "read_config_grammar.y"
+#line 382 "read_config_grammar.y"
     {
 	   SRV(server)->keepalive_max = yyvsp[0].number;
 }
     break;
 
   case 65:
-#line 384 "read_config_grammar.y"
+#line 387 "read_config_grammar.y"
     {
 #ifdef HAVE_TLS
 	   cherokee_virtual_server_t *vsrv = auto_virtual_server;
@@ -1578,7 +1582,7 @@ yyreduce:
     break;
 
   case 66:
-#line 401 "read_config_grammar.y"
+#line 404 "read_config_grammar.y"
     {
 #ifdef HAVE_TLS
 	   cherokee_virtual_server_t *vsrv = auto_virtual_server;
@@ -1597,7 +1601,7 @@ yyreduce:
     break;
 
   case 67:
-#line 418 "read_config_grammar.y"
+#line 421 "read_config_grammar.y"
     {
 #ifdef HAVE_TLS
 	   cherokee_virtual_server_t *vsrv = auto_virtual_server;
@@ -1616,7 +1620,7 @@ yyreduce:
     break;
 
   case 68:
-#line 436 "read_config_grammar.y"
+#line 439 "read_config_grammar.y"
     {
 	   ret_t ret;
 
@@ -1630,7 +1634,7 @@ yyreduce:
     break;
 
   case 69:
-#line 448 "read_config_grammar.y"
+#line 451 "read_config_grammar.y"
     {
 	   ret_t ret;
 	   cherokee_module_info_t *info;
@@ -1659,14 +1663,14 @@ yyreduce:
     break;
 
   case 70:
-#line 474 "read_config_grammar.y"
+#line 477 "read_config_grammar.y"
     {
 	   current_encoder_entry = NULL;
 }
     break;
 
   case 71:
-#line 479 "read_config_grammar.y"
+#line 482 "read_config_grammar.y"
     {
 	   linked_list_t *i;
 	   cherokee_matching_list_t *matching;
@@ -1689,7 +1693,7 @@ yyreduce:
     break;
 
   case 72:
-#line 500 "read_config_grammar.y"
+#line 503 "read_config_grammar.y"
     {
 	   linked_list_t *i;
 	   cherokee_matching_list_t *matching;
@@ -1712,7 +1716,7 @@ yyreduce:
     break;
 
   case 73:
-#line 521 "read_config_grammar.y"
+#line 524 "read_config_grammar.y"
     {
 	   FILE *file;
 
@@ -1731,14 +1735,14 @@ yyreduce:
     break;
 
   case 74:
-#line 538 "read_config_grammar.y"
+#line 541 "read_config_grammar.y"
     {
 	   SRV(server)->chroot = yyvsp[0].string;
 }
     break;
 
   case 75:
-#line 543 "read_config_grammar.y"
+#line 546 "read_config_grammar.y"
     {
 #ifdef HAVE_PTHREAD
 	   SRV(server)->ncpus = yyvsp[0].number;
@@ -1747,14 +1751,14 @@ yyreduce:
     break;
 
   case 76:
-#line 550 "read_config_grammar.y"
+#line 553 "read_config_grammar.y"
     {
 	   SRV(server)->ipv6 = yyvsp[0].number;
 }
     break;
 
   case 77:
-#line 555 "read_config_grammar.y"
+#line 558 "read_config_grammar.y"
     {
 	   struct passwd *pwd;
 	   
@@ -1771,14 +1775,14 @@ yyreduce:
     break;
 
   case 78:
-#line 570 "read_config_grammar.y"
+#line 573 "read_config_grammar.y"
     {
 	   SRV(server)->user = yyvsp[0].number;
 }
     break;
 
   case 79:
-#line 575 "read_config_grammar.y"
+#line 578 "read_config_grammar.y"
     {
 	   struct group *grp;
 
@@ -1795,14 +1799,14 @@ yyreduce:
     break;
 
   case 80:
-#line 590 "read_config_grammar.y"
+#line 593 "read_config_grammar.y"
     {
 	   SRV(server)->group = yyvsp[0].number;
 }
     break;
 
   case 81:
-#line 595 "read_config_grammar.y"
+#line 598 "read_config_grammar.y"
     {
 	   yyval.name_ptr.name = yyvsp[-3].string;
 	   yyval.name_ptr.ptr = current_handler_table_entry;
@@ -1810,7 +1814,7 @@ yyreduce:
     break;
 
   case 82:
-#line 601 "read_config_grammar.y"
+#line 604 "read_config_grammar.y"
     {
 	   yyval.name_ptr.name = yyvsp[0].string;
 	   yyval.name_ptr.ptr = current_handler_table_entry;
@@ -1818,51 +1822,51 @@ yyreduce:
     break;
 
   case 83:
-#line 608 "read_config_grammar.y"
+#line 611 "read_config_grammar.y"
     {
 	   cherokee_handler_table_entry_set (current_handler_table_entry, "url", yyvsp[0].string);
 }
     break;
 
   case 84:
-#line 613 "read_config_grammar.y"
+#line 616 "read_config_grammar.y"
     {
 	   cherokee_handler_table_entry_set (current_handler_table_entry, "filedir", yyvsp[0].string);
 }
     break;
 
   case 85:
-#line 618 "read_config_grammar.y"
+#line 621 "read_config_grammar.y"
     { cherokee_handler_table_entry_set (current_handler_table_entry, "bgcolor", yyvsp[0].string); }
     break;
 
   case 86:
-#line 621 "read_config_grammar.y"
+#line 624 "read_config_grammar.y"
     { cherokee_handler_table_entry_set (current_handler_table_entry, "text", yyvsp[0].string); }
     break;
 
   case 87:
-#line 624 "read_config_grammar.y"
+#line 627 "read_config_grammar.y"
     { cherokee_handler_table_entry_set (current_handler_table_entry, "link", yyvsp[0].string); }
     break;
 
   case 88:
-#line 627 "read_config_grammar.y"
+#line 630 "read_config_grammar.y"
     { cherokee_handler_table_entry_set (current_handler_table_entry, "vlink", yyvsp[0].string); }
     break;
 
   case 89:
-#line 630 "read_config_grammar.y"
+#line 633 "read_config_grammar.y"
     { cherokee_handler_table_entry_set (current_handler_table_entry, "alink", yyvsp[0].string); }
     break;
 
   case 90:
-#line 633 "read_config_grammar.y"
+#line 636 "read_config_grammar.y"
     { cherokee_handler_table_entry_set (current_handler_table_entry, "headerfile", yyvsp[0].string); }
     break;
 
   case 91:
-#line 637 "read_config_grammar.y"
+#line 640 "read_config_grammar.y"
     {
 	   linked_list_t *i;
 
@@ -1892,14 +1896,14 @@ yyreduce:
     break;
 
   case 93:
-#line 667 "read_config_grammar.y"
+#line 670 "read_config_grammar.y"
     {
 	   yyval.string = yyvsp[0].string;
 }
     break;
 
   case 94:
-#line 673 "read_config_grammar.y"
+#line 675 "read_config_grammar.y"
     {
 	   linked_list_t *i = yyvsp[-1].id_list;
 	   CHEROKEE_NEW(vsrv, virtual_server);
@@ -1921,7 +1925,7 @@ yyreduce:
     break;
 
   case 95:
-#line 690 "read_config_grammar.y"
+#line 692 "read_config_grammar.y"
     {
 
 	   current_virtual_server = NULL;
@@ -1929,7 +1933,7 @@ yyreduce:
     break;
 
   case 96:
-#line 697 "read_config_grammar.y"
+#line 699 "read_config_grammar.y"
     {
 	   int name_len;
 
@@ -1946,7 +1950,7 @@ yyreduce:
     break;
 
   case 97:
-#line 711 "read_config_grammar.y"
+#line 713 "read_config_grammar.y"
     {
 	   /* Basic checks
 	    */
@@ -2011,14 +2015,14 @@ out:
     break;
 
   case 98:
-#line 775 "read_config_grammar.y"
+#line 777 "read_config_grammar.y"
     {	   
 	   directory_content_tmp.handler_name = yyvsp[0].name_ptr.name;
 }
     break;
 
   case 99:
-#line 781 "read_config_grammar.y"
+#line 783 "read_config_grammar.y"
     {
 	   int len;
 	   char *new_fdir;
@@ -2031,13 +2035,13 @@ out:
     break;
 
   case 100:
-#line 792 "read_config_grammar.y"
+#line 794 "read_config_grammar.y"
     {
 }
     break;
 
   case 101:
-#line 796 "read_config_grammar.y"
+#line 798 "read_config_grammar.y"
     {
 	   cherokee_buffer_t *realm;
 	   realm = directory_content_tmp.entry->auth_realm;
@@ -2048,7 +2052,7 @@ out:
     break;
 
   case 102:
-#line 805 "read_config_grammar.y"
+#line 807 "read_config_grammar.y"
     {
 	   ret_t ret;
 	   cherokee_module_info_t *info;
@@ -2070,12 +2074,12 @@ out:
     break;
 
   case 107:
-#line 834 "read_config_grammar.y"
+#line 836 "read_config_grammar.y"
     { cherokee_handler_table_entry_set (current_handler_table_entry, "file", yyvsp[0].string); }
     break;
 
   case 108:
-#line 839 "read_config_grammar.y"
+#line 841 "read_config_grammar.y"
     {
 	   ret_t ret;
 	   int   len;
@@ -2107,12 +2111,12 @@ out:
     break;
 
   case 109:
-#line 870 "read_config_grammar.y"
+#line 872 "read_config_grammar.y"
     {
 	   linked_list_t *i = yyvsp[0].id_list;
 
 	   while (i != NULL) {
-			 cherokee_list_add (&SRV(server)->index_list, i->string);
+			 cherokee_list_add_tail (&SRV(server)->index_list, i->string);
 			 i = i->next;
 	   }
 
@@ -2121,7 +2125,7 @@ out:
     break;
 
   case 110:
-#line 882 "read_config_grammar.y"
+#line 884 "read_config_grammar.y"
     {
 	   cherokee_virtual_server_t *vsrv = auto_virtual_server;
 	   
@@ -2135,7 +2139,7 @@ out:
     break;
 
   case 111:
-#line 894 "read_config_grammar.y"
+#line 896 "read_config_grammar.y"
     {
 	   cherokee_virtual_server_t *vsrv = auto_virtual_server;
 	   
@@ -2152,7 +2156,7 @@ out:
     }
 
 /* Line 999 of yacc.c.  */
-#line 2156 "read_config_grammar.c"
+#line 2160 "read_config_grammar.c"
 
   yyvsp -= yylen;
   yyssp -= yylen;
@@ -2346,7 +2350,7 @@ yyreturn:
 }
 
 
-#line 905 "read_config_grammar.y"
+#line 907 "read_config_grammar.y"
 
 
 
