@@ -960,3 +960,68 @@ cherokee_server_daemonize (cherokee_server_t *srv)
 
 	return ret_ok;
 }
+
+
+ret_t 
+cherokee_server_get_active_conns (cherokee_server_t *srv, int *num)
+{
+	int     active = 0;
+	list_t *thread, *i;
+
+	/* Active connections number
+	 */
+	list_for_each (thread, &srv->thread_list) {
+		active += THREAD(thread)->active_list_num;
+	}
+	
+	active += srv->main_thread->active_list_num;
+
+	/* Return out parameters
+	 */
+	*num = active;
+
+	return ret_ok;
+}
+
+
+ret_t 
+cherokee_server_get_reusable_conns (cherokee_server_t *srv, int *num)
+{
+	int     reusable = 0;
+	list_t *thread, *i;
+
+	/* Reusable connections
+	 */
+	list_for_each (thread, &srv->thread_list) {
+		list_for_each (i, &THREAD(thread)->reuse_list) {
+			reusable++;
+		}
+	}
+	list_for_each (i, &THREAD(srv->main_thread)->reuse_list) {
+		reusable++;
+	}
+
+	/* Return out parameters
+	 */
+	*num = reusable;
+
+	return ret_ok;
+}
+
+
+ret_t 
+cherokee_server_get_total_traffic (cherokee_server_t *srv, int *rx, int *tx)
+{
+	list_t *i;
+
+	*rx = srv->vserver_default->data.rx;
+	*tx = srv->vserver_default->data.tx;
+
+	list_for_each (i, &srv->vservers) {
+		*rx += VSERVER(i)->data.rx;
+		*tx += VSERVER(i)->data.tx;
+	}
+
+	return ret_ok;
+}
+
