@@ -143,6 +143,9 @@ ret_t cherokee_server_daemonize       (cherokee_server_t *srv);
 ret_t cherokee_server_read_config_file    (cherokee_server_t *srv, char *filename);
 ret_t cherokee_server_read_config_string  (cherokee_server_t *srv, char *string);
 
+ret_t cherokee_server_get_active_conns   (cherokee_server_t *srv, int *num);
+ret_t cherokee_server_get_reusable_conns (cherokee_server_t *srv, int *num);
+ret_t cherokee_server_get_total_traffic  (cherokee_server_t *srv, int *rx, int *tx);
 
 /* System signal callback
  */
